<?php
class Config
{
	private $dbFile = '/etc/vpnportal/vpnportal.sqlite';

	const STAGE_INITIAL = 0;
	const STAGE_PASSWORD_CONFIGURED = 1;
	const STAGE_SERVER_CONFIGURED = 2;
	const STAGE_AUTOSETUP_CONFIGURED = 3;
	const STAGE_PRODUCTION = 4;

	function __construct() {
		$this->pdb = new PDO('sqlite:' . $this->dbFile);
	}

	function __destruct() {
		$this->pdb = null;
	}

	function getVersion()
	{
		$query = "SELECT Version FROM ConfigStatus";
		$stmt = $this->pdb->prepare($query);
		$stmt->execute();
		$res = $stmt->fetch(PDO::FETCH_ASSOC);
		if ($res==null) return 0;
		return $res['Version'];
	}

	function getStage()
	{
		$query = "SELECT Stage FROM ConfigStatus";
		$stmt = $this->pdb->prepare($query);
		$stmt->execute();
		$res = $stmt->fetch(PDO::FETCH_ASSOC);
		if ($res==null) return 0;
		return $res['Stage'];
	}

	function setStage($stage)
	{
		$query = "UPDATE ConfigStatus SET Stage=:stage";
		$stmt = $this->pdb->prepare($query);
		$stmt->execute(array(':stage' => $stage));
	}

	function getExpertMode()
	{
		$query = "SELECT ExpertMode FROM ConfigStatus";
		$stmt = $this->pdb->prepare($query);
		$stmt->execute();
		$res = $stmt->fetch(PDO::FETCH_ASSOC);
		if ($res==null) return 0;
		return $res['ExpertMode'];
	}

	function setExpertMode($expertMode)
	{
		$query = "UPDATE ConfigStatus SET ExpertMode=:expertmode";
		$stmt = $this->pdb->prepare($query);
		$stmt->execute(array(':expertmode' => $expertMode));
	}

	function getAvailableNetworks($currentNetwork)
	{
		$query = "SELECT V4NetworkAddress FROM OpenvpnSettings";
		$stmt = $this->pdb->prepare($query);
		$stmt->execute();
		$res = $stmt->fetch(PDO::FETCH_ASSOC);
		$openVpnNet=explode(".", $res['V4NetworkAddress']);
		$openVpnNet=$openVpnNet[1];
	
		$query = "SELECT V4NetworkAddress FROM MobileipSettings";
		$stmt = $this->pdb->prepare($query);
		$stmt->execute();
		$res = $stmt->fetch(PDO::FETCH_ASSOC);
		$mobileIpNet=explode(".", $res['V4NetworkAddress']);
		$mobileIpNet=$mobileIpNet[1];
	
		$query = "SELECT V4LeaseStartAddress FROM L2tpIpsecSettings";
		$stmt = $this->pdb->prepare($query);
		$stmt->execute();
		$res = $stmt->fetch(PDO::FETCH_ASSOC);
		$l2tpNet=explode(".", $res['V4LeaseStartAddress']);
		$l2tpNet=$l2tpNet[1];

		$currentNetwork=explode(".", $currentNetwork);
		$currentNetwork=$currentNetwork[1];

		$nets=array();
		for ($i=0; $i<254; $i+=2)
		{
			if ((($i!=$openVpnNet) && ($i!=$mobileIpNet) && ($i!=$l2tpNet)) ||
			    ($i==$currentNetwork))
			{
				array_push($nets, "10." . $i . ".0.0");
			}
		}
		return $nets;
	}
}

$cfg = new Config();

?>
