<?php

require_once("config.php");

class LicEngine
{
	const MAGIC_COOKIE = "8A51B6xA19Bx/edjampQy/t3BXsjEk";
	const FEATURE_OPENVPN = 7;
	const FEATURE_MOBILEIP = 6;

	function checksum($key)
	{
		$data = substr(strtoupper($key), 0, 27) . LicEngine::MAGIC_COOKIE;
		$crc = crc32($data);
		return $this->decHexPadded($crc);
	}

	function decHexPadded($dec)
	{
		$hex = dechex($dec);
		while (strlen($hex)<8)
		{
			$hex = '0' . $hex;
		}
		return strtoupper($hex);
	}

	function checkKey($key, &$openvpn, &$mobileip)
	{
		$openvpn=0;
		$mobileip=0;

		if (strlen($key)!=35) return FALSE;
		$sum = $this->checksum($key);
		
		$features = hexdec(substr(strtoupper($key), 9, 2));
		$openvpn = ($features & (1<<LicEngine::FEATURE_OPENVPN)) ? 1 : 0;
		$mobileip = ($features & (1<<LicEngine::FEATURE_MOBILEIP)) ? 1 : 0;

		return (strcmp(substr($key, 27, 8),$sum)==0);
	}

	function isLicensedMobileIp()
	{
		$openvpn=0;
		$mobileip=0;
		$key=$this->loadLicenseKey();
		if ($this->checkKey($key, $openvpn, $mobileip))
		{
			return $mobileip;
		} else {
			return 0;
		}
	}

	function haveValidLicenseKey()
	{
		$openvpn=0;
		$mobileip=0;
		$key=$this->loadLicenseKey();
		return $this->checkKey($key, $openvpn, $mobileip);
	}

	function haveLicenseAgreement()
	{
		global $cfg;
		$query = "SELECT LicenseAgreement FROM ConfigStatus";
		$res = $cfg->pdb->query($query)->fetch(PDO::FETCH_ASSOC);
		$key = $res['LicenseAgreement'];
		return $key;
	}

	function loadLicenseKey()
	{
		global $cfg;
		$query = "SELECT LicenseKey FROM ConfigStatus";
		$res = $cfg->pdb->query($query)->fetch(PDO::FETCH_ASSOC);
		$key = $res['LicenseKey'];
		return $key;
	}

	function saveLicenseKey($key)
	{
		global $cfg;
		$query = "UPDATE ConfigStatus SET LicenseKey=:key";
		$stmt = $cfg->pdb->prepare($query);
		$stmt->execute(array(':key' => $key));
	}

	function saveLicenseAgreement()
	{
		global $cfg;
		$query = "UPDATE ConfigStatus SET LicenseAgreement=date('now')";
		$cfg->pdb->query($query);
	}
}

$licEngine = new LicEngine();

?>
