<?

require_once("lic-engine.php");

/*
 * calculate CIDR to netmask 
 */
function cidr2netmask($cidr) 
{
	return long2ip(~((1 << (32 - $cidr)) - 1));
}

/*  
 * make network address from address/netmask
 */
function netaddress($address, $netmask)
{
	if ($address == "" || $netmask == "") return false;

	$a = ip2long($address);
	$n = ip2long($netmask);

	return long2ip($a & $n);
}

/*
 * make broadcast address from address/netmask
 */
function bcaddress($address, $netmask)
{
	if ($address == "" || $netmask == "") return false;

	$a = ip2long($address);
	$n = ip2long($netmask);

	return long2ip(($a & $n) | (~$n));
}

/*
 * check for valid hostname 
 */
function valid_hostname ($hostname)
{
	return true;
}

/* 
 * check for valid address 
 */
function valid_address ($address)
{
	return filter_var($address, FILTER_VALIDATE_IP, FILTER_FLAG_IPV4);
}

/*  
 * check for valid netmask 
 */
function valid_netmask ($netmask)
{
	return filter_var($netmask, FILTER_VALIDATE_IP, FILTER_FLAG_IPV4);
}

/*  
 * check for valid network address and netmask pair 
 */
function valid_network ($address, $netmask)
{
	$res=filter_var($address, FILTER_VALIDATE_IP, FILTER_FLAG_IPV4);
	if ($res==0) return 0;
	return filter_var($netmask, FILTER_VALIDATE_IP, FILTER_FLAG_IPV4);
}

/*  
 * check for valid port
 */
function valid_port ($port)
{
	if (!is_numeric($port)) return false;
	if ($port > 1 && $port < 65536) return true;
	return false;
}

/*  
 * status message handling
 */

$VP_ERRORS="";
$VP_INFO="";
$VP_SUCCESS="";

function vp_error ($err_msg)
{
	global $VP_ERRORS;
	$VP_ERRORS=$VP_ERRORS . $err_msg . "</br />";
}

function vp_info ($err_msg)
{
	global $VP_INFO;
	$VP_INFO=$VP_INFO . $err_msg . "</br />";
}

function vp_success ($err_msg)
{
	global $VP_SUCCESS;
	$VP_SUCCESS=$VP_SUCCESS . $err_msg . "</br />";
}

function vp_is_error ()
{
	global $VP_ERRORS;
	return (strlen($VP_ERRORS)!=0);
}

function vp_display_status ()
{
	global $VP_ERRORS;
	global $VP_INFO;
	global $VP_SUCCESS;
	if (strlen($VP_ERRORS))
		echo "<font color=\"red\"> $VP_ERRORS <br /></font>";
	if (strlen($VP_INFO))
		echo "<font color=\"yellow\"> $VP_INFO <br /></font>";
	if (strlen($VP_SUCCESS))
		echo "<font color=\"green\"> $VP_SUCCESS <br /></font>";
}

/*  
 * check for mobile ip availability (installed / licensed)
 */
function mobileIpAvailable()
{
	global $licEngine;
	return file_exists("/usr/sbin/home-agent");
}

/*  
 * check if l2tp ipsec enabled
 */
function l2tpIpsecEnabled($cfg)
{
	$query = "SELECT Enabled FROM L2tpIpsecSettings";
	$res = $cfg->pdb->query($query)->fetch(PDO::FETCH_ASSOC);
	if ($res==null) return false;
	return $res['Enabled'];
}

/*  
 * Check for valid user
 */
function validUser($cfg, $username, $password)
{
	$query = "SELECT Username, Password FROM Users WHERE Username=:username";
	$stmt = $cfg->pdb->prepare($query);
	$stmt->execute(array(':username' => $username));
	$res = $stmt->fetch(PDO::FETCH_ASSOC);
	if ($res==null) return false;
	return ($res['Password']==$password);
}

function isAdminDefined($cfg)
{
	$query = "SELECT COUNT(*) FROM Users WHERE Username='admin'";
	$res = $cfg->pdb->query($query)->fetchColumn();
	return ($res>0);
}

function isMcrActive()
{
	return (is_dir("/etc/mcrinfo"));
}

	function connectedOpenVpnClients($port) {
		$clients = Array();

		$sock = @fsockopen("127.0.0.1", $port, $errno, $errstr, 2);
		if (!$sock) return false;

		fwrite($sock, "log off\n");
		fwrite($sock, "status 3\n");
		sleep(1);

		$start = -1;
		for ($i = 0; $i<300; $i++) {
			$line = fgets($sock);
			if (!$line || strstr($line, "END")) break;

			if (strncmp($line, "CLIENT_LIST", 11) != 0) continue;
			if ($start == -1) $start = $i;

			// quit early in case of too many lines
			if (($i - $start) > 256) break;

			// split line into string chunks
			$p = preg_split('/\s+/', $line);

			// check duplicates
			$skip = false;
			foreach ($clients as $prev) {
				if ($prev["name"] == $p[1] && $prev["since"] > $p[11]) $skip = true;
			}
			if ($skip) continue;

			$c = Array();
			$c["name"] = $p[1];
			$from = explode(":", $p[2]);
			$c["source"] = $from[0];
			$c["sport"] = $from[1];
			$c["address"] = $p[3];
			$c["rcvd"] = $p[4];
			$c["sent"] = $p[5];
			$c["since"] = $p[11];
			$clients[$c["name"]] = $c;
		}
		fwrite($sock, "quit\n");
		fclose($sock);

		return $clients;
	}

	function isClientOnline($clients, $ip) {
		foreach ($clients as $client)
		if ($client['address'] == $ip)
			return true;
		return false;
	}

?>
